overview
========

**aliyun-img-utils** provides a command line utility for handling
images in the Aliyun Cloud.

Installation
============

To install the package use the following commands as root:

```shell
$ zypper ar http://download.opensuse.org/repositories/Cloud:/Tools/<distribution>
$ zypper refresh
$ zypper in python3-aliyun-img-utils
```

Requirements
============

- oss2
- Click

CLI Overview
============

The CLI provides multiple subcommands to handle images:

...

Issues/Enhancements
===================

Please submit issues and requests to
[Github](https://github.com/SUSE-Enceladus/aliyun-img-utils/issues).

Contributing
============

Contributions to **aliyun-img-utils** are welcome and encouraged. See
[CONTRIBUTING](https://github.com/SUSE-Enceladus/aliyun-img-utils/blob/master/CONTRIBUTING.md)
for info on getting started.

License
=======

Copyright (c) 2020 SUSE LLC.

Distributed under the terms of GPL-3.0+ license, see
[LICENSE](https://github.com/SUSE-Enceladus/aliyun-img-utils/blob/master/LICENSE)
for details.
